[llvm-commits] CVS: llvm/include/llvm/CodeGen/ValueTypes.h

Dan Gohman djg at cray.com
Thu Jun 14 15:58:25 PDT 2007



Changes in directory llvm/include/llvm/CodeGen:

ValueTypes.h updated: 1.34 -> 1.35
---
Log message:

Rename MVT::getVectorBaseType to MVT::getVectorElementType.


---
Diffs of the changes:  (+2 -2)

 ValueTypes.h |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)


Index: llvm/include/llvm/CodeGen/ValueTypes.h
diff -u llvm/include/llvm/CodeGen/ValueTypes.h:1.34 llvm/include/llvm/CodeGen/ValueTypes.h:1.35
--- llvm/include/llvm/CodeGen/ValueTypes.h:1.34	Sat Apr 28 00:38:52 2007
+++ llvm/include/llvm/CodeGen/ValueTypes.h	Thu Jun 14 17:58:02 2007
@@ -129,9 +129,9 @@
   ///
   ValueType getVectorType(ValueType VT, unsigned NumElements);
     
   /// MVT::getVectorBaseType - Given a packed vector type, return the type of
   /// each element.
-  static inline ValueType getVectorBaseType(ValueType VT) {
+  static inline ValueType getVectorElementType(ValueType VT) {
     switch (VT) {
     default: assert(0 && "Invalid vector type!");
     case v8i8 :
@@ -129,9 +129,9 @@
   ValueType getVectorType(ValueType VT, unsigned NumElements);
     
-  /// MVT::getVectorBaseType - Given a packed vector type, return the type of
+  /// MVT::getVectorElementType - Given a packed vector type, return the type of
   /// each element.






More information about the llvm-commits mailing list